""" Version info for objbrowser
"""
import os

DEBUGGING = False # TODO: False

PROGRAM_NAME = 'objbrowser'
PROGRAM_VERSION = '1.0.0a'
PROGRAM_URL = 'https://github.com/titusjan/objbrowser'
PROGRAM_DIRECTORY = os.path.abspath(os.path.dirname(__file__))
